@@ -1,10 +1,5 @@
 package App::depak;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-29'; # DATE
-our $DIST = 'App-depak'; # DIST
-our $VERSION = '0.583'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -17,6 +12,11 @@ use File::chdir;
 use File::Slurper qw(write_binary read_binary);
 use version;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-21'; # DATE
+our $DIST = 'App-depak'; # DIST
+our $VERSION = '0.584'; # VERSION
+
 my @ALLOW_XS = qw(List::MoreUtils version::vxs);
 
 our %SPEC;
@@ -350,6 +350,7 @@ sub _pack {
 
     my $res;
     $pack_args{preamble}  = "$shebang\n\n";
+    $pack_args{preamble} .= "# code after shebang\n$self->{code_after_shebang}\n\n" if defined $self->{code_after_shebang};
     $pack_args{postamble} = "\n$script";
     $pack_args{put_hook_at_the_end} = $self->{put_hook_at_the_end};
     if ($self->{pack_method} eq 'datapack') {
@@ -458,6 +459,11 @@ _
             pos => 1,
             tags => ['category:output'],
         },
+        code_after_shebang => {
+            summary => 'Add some code right after shebang line',
+            schema => 'str*',
+            tags => ['category:output'],
+        },
         include_module => {
             summary => 'Include extra modules',
             'summary.alt.plurality.singular' => 'Include an extra module',
@@ -898,7 +904,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.583 of App::depak (from Perl distribution App-depak), released on 2020-04-29.
+This document describes version 0.584 of App::depak (from Perl distribution App-depak), released on 2021-10-21.
 
 =head1 SYNOPSIS
 
@@ -913,7 +919,7 @@ See L<depak>.
 
 Usage:
 
- depak(%args) -> [status, msg, payload, meta]
+ depak(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Pack your dependencies onto your script file.
 
@@ -939,6 +945,10 @@ or:
 
  % depak script output --args-json '["--foo",2,"bar baz"]'
 
+=item * B<code_after_shebang> => I<str>
+
+Add some code right after shebang line.
+
 =item * B<debug_keep_tempdir> => I<bool>
 
 Keep temporary directory for debugging.
@@ -1164,12 +1174,12 @@ C<require> methods (because those methods actually run your script).
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -1181,6 +1191,50 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-depak>
 
 Source repository is at L<https://github.com/perlancar/perl-App-depak>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Paul Fenwick Steven Haryanto
+
+=over 4
+
+=item *
+
+Paul Fenwick <pjf@perltraining.com.au>
+
+=item *
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=back
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-depak>
@@ -1189,15 +1243,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
