@@ -1,12 +1,15 @@
 package Perinci::CmdLine::depak;
 
-our $DATE = '2020-04-29'; # DATE
-our $VERSION = '0.583'; # VERSION
-
 use 5.010;
+use strict;
 use Log::ger;
 use parent qw(Perinci::CmdLine::Lite);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-21'; # DATE
+our $DIST = 'App-depak'; # DIST
+our $VERSION = '0.584'; # VERSION
+
 sub hook_before_read_config_file {
     my ($self, $r) = @_;
 
@@ -65,7 +68,7 @@ Perinci::CmdLine::depak - Subclass of Perinci::CmdLine::Lite to set config_profi
 
 =head1 VERSION
 
-This document describes version 0.583 of Perinci::CmdLine::depak (from Perl distribution App-depak), released on 2020-04-29.
+This document describes version 0.584 of Perinci::CmdLine::depak (from Perl distribution App-depak), released on 2021-10-21.
 
 =head1 DESCRIPTION
 
@@ -89,6 +92,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-depak>
 
 Source repository is at L<https://github.com/perlancar/perl-App-depak>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-depak>
@@ -97,15 +128,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
